@@ -8,7 +8,7 @@ use strict;
 # Set the version for CPAN
 use vars qw{$VERSION $XS_COMPATIBLE @XS_EXCLUDE};
 BEGIN {
-	$VERSION       = '1.214_02';
+	$VERSION       = '1.216_01';
 	$XS_COMPATIBLE = '0.845';
 	@XS_EXCLUDE    = ();
 }
@@ -91,7 +91,7 @@ The cause of this problem was Perl's complex and dynamic grammar.
 Although there is typically not a huge diversity in the grammar of most
 Perl code, certain issues cause large problems when it comes to parsing.
 
-Indeed, quite early in Perl's history Tom Christenson introduced the Perl
+Indeed, quite early in Perl's history Tom Christiansen introduced the Perl
 community to the quote I<"Nothing but perl can parse Perl">, or as it is
 more often stated now as a truism:
 
@@ -194,7 +194,7 @@ What are the things that people might want a "Perl parser" for.
 Analyzing the contents of a Perl document to automatically generate
 documentation, in parallel to, or as a replacement for, POD documentation.
 
-Allow an indexer to to locate and process all the comments and
+Allow an indexer to locate and process all the comments and
 documentation from code for "full text search" applications.
 
 =item Structural and Quality Analysis
@@ -541,8 +541,8 @@ via the included L<PPI::Dumper>).
   PPI::Document
     PPI::Token::Comment                '#!/usr/bin/perl\n'
     PPI::Token::Whitespace             '\n'
-    PPI::Statement::Expression
-      PPI::Token::Bareword             'print'
+    PPI::Statement
+      PPI::Token::Word                 'print'
       PPI::Structure::List             ( ... )
         PPI::Token::Whitespace         ' '
         PPI::Statement::Expression
@@ -551,13 +551,13 @@ via the included L<PPI::Dumper>).
       PPI::Token::Structure            ';'
     PPI::Token::Whitespace             '\n'
     PPI::Token::Whitespace             '\n'
-    PPI::Statement::Expression
-      PPI::Token::Bareword             'exit'
+    PPI::Statement
+      PPI::Token::Word                 'exit'
       PPI::Structure::List             ( ... )
       PPI::Token::Structure            ';'
     PPI::Token::Whitespace             '\n'
 
-Please note that in this this example, strings are only listed for the
+Please note that in this example, strings are only listed for the
 B<actual> L<PPI::Token> that contains that string. Structures are listed
 with the type of brace characters it represents noted.
 
@@ -568,14 +568,14 @@ whitespace. Here it is again, sans the distracting whitespace tokens.
 
   PPI::Document
     PPI::Token::Comment                '#!/usr/bin/perl\n'
-    PPI::Statement::Expression
-      PPI::Token::Bareword             'print'
+    PPI::Statement
+      PPI::Token::Word                 'print'
       PPI::Structure::List             ( ... )
         PPI::Statement::Expression
           PPI::Token::Quote::Double    '"Hello World!"'
       PPI::Token::Structure            ';'
-    PPI::Statement::Expression
-      PPI::Token::Bareword             'exit'
+    PPI::Statement
+      PPI::Token::Word                 'exit'
       PPI::Structure::List             ( ... )
       PPI::Token::Structure            ';'
 
@@ -749,17 +749,17 @@ you are B<strongly> encouraged to do so, as the author currently maintains
 over 100 modules and it can take some time to deal with non-"Critical" bug
 reports or patches.
 
-This will also guarentee that your issue will be addressed in the next
+This will also guarantee that your issue will be addressed in the next
 release of the module.
 
 For large changes though, please consider creating a branch so that they
 can be properly reviewed and trialed before being applied to the trunk.
 
 If you cannot provide a direct test or fix, or don't have time to do so,
-then regular bug reports are still accepted and appreciated via the CPAN
-bug tracker.
+then regular bug reports are still accepted and appreciated via the
+GitHub bug tracker.
 
-L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=PPI>
+L<https://github.com/adamkennedy/PPI/issues>
 
 For other issues or questions, contact the C<Parse::Perl> project mailing
 list.
