@@ -37,7 +37,7 @@ use Params::Util qw{_INSTANCE};
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '1.214_02';
+	$VERSION = '1.216_01';
 }
 
 
@@ -92,7 +92,7 @@ made much clearer. True/false value, on by default.
 
 Should the dumper show comment tokens. In situations where you have
 a lot of comments, the code can often be made clearer by ignoring
-comment tokens. True/value value, on by default.
+comment tokens. True/false value, on by default.
 
 =item locations
 
@@ -266,6 +266,7 @@ sub _element_string {
 			my $content = $Element->content;
 			$content =~ s/\n/\\n/g;
 			$content =~ s/\t/\\t/g;
+			$content =~ s/\f/\\f/g;
 			$string .= "  \t'$content'";
 		}
 
