@@ -29,8 +29,6 @@ described in L<perlsyn>.
 C<PPI::Statement::Given> has no methods beyond those provided by the
 standard L<PPI::Structure>, L<PPI::Node> and L<PPI::Element> methods.
 
-Got any ideas for methods? Submit a report to rt.cpan.org!
-
 =cut
 
 use strict;
@@ -38,12 +36,12 @@ use PPI::Statement ();
 
 use vars qw{$VERSION @ISA};
 BEGIN {
-	$VERSION = '1.214_02';
+	$VERSION = '1.216_01';
 	@ISA     = 'PPI::Statement';
 }
 
 # Lexer clues
-sub __LEXER__normal { '' }
+sub __LEXER__normal() { '' }
 
 sub _complete {
 	my $child = $_[0]->schild(-1);
@@ -63,7 +61,7 @@ sub _complete {
 #####################################################################
 # PPI::Node Methods
 
-sub scope () { 1 }
+sub scope() { 1 }
 
 1;
 
