@@ -45,12 +45,12 @@ use PPI::Statement ();
 
 use vars qw{$VERSION @ISA};
 BEGIN {
-	$VERSION = '1.214_02';
+	$VERSION = '1.216_01';
 	@ISA     = 'PPI::Statement';
 }
 
 # A null statement is not significant
-sub significant { '' }
+sub significant() { '' }
 
 1;
 
