@@ -37,12 +37,12 @@ use PPI::Statement ();
 
 use vars qw{$VERSION @ISA};
 BEGIN {
-	$VERSION = '1.214_02';
+	$VERSION = '1.216_01';
 	@ISA     = 'PPI::Statement';
 }
 
 # Lexer clue
-sub __LEXER__normal { '' }
+sub __LEXER__normal() { '' }
 
 sub _complete {
 	my $child = $_[0]->schild(-1);
