@@ -37,8 +37,6 @@ statements, as described in L<perlsyn>.
 C<PPI::Structure::When> has no methods beyond those provided by the
 standard L<PPI::Structure>, L<PPI::Node> and L<PPI::Element> methods.
 
-Got any ideas for methods? Submit a report to rt.cpan.org!
-
 =cut
 
 use strict;
@@ -46,12 +44,12 @@ use PPI::Statement ();
 
 use vars qw{$VERSION @ISA};
 BEGIN {
-	$VERSION = '1.214_02';
+	$VERSION = '1.216_01';
 	@ISA     = 'PPI::Statement';
 }
 
 # Lexer clues
-sub __LEXER__normal { '' }
+sub __LEXER__normal() { '' }
 
 sub _complete {
 	my $child = $_[0]->schild(-1);
@@ -71,7 +69,7 @@ sub _complete {
 #####################################################################
 # PPI::Node Methods
 
-sub scope {
+sub scope() {
 	1;
 }
 
