@@ -38,8 +38,6 @@ and any other block braces.
 C<PPI::Structure::Block> has no methods beyond those provided by the
 standard L<PPI::Structure>, L<PPI::Node> and L<PPI::Element> methods.
 
-Got any ideas for methods? Submit a report to rt.cpan.org!
-
 =cut
 
 use strict;
@@ -47,7 +45,7 @@ use PPI::Structure ();
 
 use vars qw{$VERSION @ISA};
 BEGIN {
-	$VERSION = '1.214_02';
+	$VERSION = '1.216_01';
 	@ISA     = 'PPI::Structure';
 }
 
@@ -59,7 +57,7 @@ BEGIN {
 # PPI::Element Methods
 
 # This is a scope boundary
-sub scope { 1 }
+sub scope() { 1 }
 
 1;
 
