@@ -28,8 +28,6 @@ treated by Perl (and thus by us) as a single string.
 This class provides some additional methods beyond those provided by its
 L<PPI::Token> and L<PPI::Element> parent classes.
 
-Got any ideas for methods? Submit a report to rt.cpan.org!
-
 =cut
 
 use strict;
@@ -37,7 +35,7 @@ use PPI::Token ();
 
 use vars qw{$VERSION @ISA};
 BEGIN {
-	$VERSION = '1.214_02';
+	$VERSION = '1.216_01';
 	@ISA     = 'PPI::Token';
 }
 
@@ -129,14 +127,12 @@ sub __TOKENIZER__scan_for_end {
 	my $depth = 0;
 	while ( exists $t->{line} ) {
 		# Get the search area
-		my $search = $t->{line_cursor}
-			? substr( $t->{line}, $t->{line_cursor} )
-			: $t->{line};
+		pos $t->{line} = $t->{line_cursor};
 
 		# Look for a match
-		unless ( $search =~ /^((?:\\.|[^()])*?[()])/ ) {
+		unless ( $t->{line} =~ /\G((?:\\.|[^()])*?[()])/gc ) {
 			# Load in the next line and push to first character
-			$string .= $search;
+			$string .= substr( $t->{line}, $t->{line_cursor} );
 			$t->_fill_line(1) or return \$string;
 			$t->{line_cursor} = 0;
 			next;
@@ -146,7 +142,7 @@ sub __TOKENIZER__scan_for_end {
 		$string .= $1;
 		$t->{line_cursor} += length $1;
 
-		# Alter the depth and continue if we arn't at the end
+		# Alter the depth and continue if we aren't at the end
 		$depth += ($1 =~ /\($/) ? 1 : -1 and next;
 
 		# Found the end
