@@ -44,11 +44,11 @@ use PPI::Token ();
 
 use vars qw{$VERSION @ISA};
 BEGIN {
-	$VERSION = '1.214_02';
+	$VERSION = '1.216_01';
 	@ISA     = 'PPI::Token';
 }
 
-sub significant { '' }
+sub significant() { '' }
 
 
 
