@@ -63,12 +63,12 @@ use PPI::Token ();
 
 use vars qw{$VERSION @ISA};
 BEGIN {
-	$VERSION = '1.214_02';
+	$VERSION = '1.216_01';
 	@ISA     = 'PPI::Token';
 }
 
 ### XS -> PPI/XS.xs:_PPI_Token_Comment__significant 0.900+
-sub significant { '' }
+sub significant() { '' }
 
 # Most stuff goes through __TOKENIZER__commit.
 # This is such a rare case, do char at a time to keep the code small
