@@ -47,7 +47,7 @@ use PPI::Token::Unknown ();
 
 use vars qw{$VERSION @ISA %magic};
 BEGIN {
-	$VERSION = '1.214_02';
+	$VERSION = '1.216_01';
 	@ISA     = 'PPI::Token::Symbol';
 
 	# Magic variables taken from perlvar.
@@ -69,46 +69,6 @@ BEGIN {
 	}
 }
 
-=pod
-
-=begin testing __TOKENIZER_on_char 30
-
-my $document = PPI::Document->new(\<<'END_PERL');
-$[;			# Magic  $[
-$$;			# Magic  $$
-%-;			# Magic  %-
-$#-;			# Magic  $#-
-$$foo;			# Symbol $foo		Dereference of $foo
-$^W;			# Magic  $^W
-$^WIDE_SYSTEM_CALLS;	# Magic  $^WIDE_SYSTEM_CALLS
-${^MATCH};		# Magic  ${^MATCH}
-@{^_Bar};		# Magic  @{^_Bar}
-${^_Bar}[0];		# Magic  @{^_Bar}
-%{^_Baz};		# Magic  %{^_Baz}
-${^_Baz}{burfle};	# Magic  %{^_Baz}
-$${^MATCH};		# Magic  ${^MATCH}	Dereference of ${^MATCH}
-\${^MATCH};		# Magic  ${^MATCH}
-END_PERL
-
-isa_ok( $document, 'PPI::Document' );
-
-$document->index_locations();
-
-my $symbols = $document->find( 'PPI::Token::Symbol' );
-
-is( scalar(@$symbols), 14, 'Found 14 symbols' );
-my $comments = $document->find( 'PPI::Token::Comment' );
-
-foreach my $token ( @$symbols ) {
-	my ($hash, $class, $name, $remk) =
-		split '\s+', $comments->[$token->line_number - 1], 4;
-	isa_ok( $token, "PPI::Token::$class" );
-	is( $token->symbol, $name, $remk || "The symbol is $name" );
-}
-
-=end testing
-
-=cut
 
 sub __TOKENIZER__on_char {
 	my $t = $_[1];
@@ -124,7 +84,7 @@ sub __TOKENIZER__on_char {
 
 		if ( $c =~ /^(\$(?:\_[\w:]|::))/ or $c =~ /^\$\'[\w]/ ) {
 			# If and only if we have $'\d, it is not a
-			# symbol. (this was apparently a concious choice)
+			# symbol. (this was apparently a conscious choice)
 			# Note that $::0 on the other hand is legal
 			if ( $c =~ /^\$\'\d$/ ) {
 				# In this case, we have a magic plus a digit.
@@ -151,8 +111,8 @@ sub __TOKENIZER__on_char {
 		if ( $c eq '$${' ) {
 			# This _might_ be a dereference of one of the
 			# control-character symbols.
-			my $line = substr $t->{line}, $t->{line_cursor} + 1;
-			if ( $line =~ m/$PPI::Token::Unknown::CURLY_SYMBOL/ ) {
+			pos $t->{line} = $t->{line_cursor} + 1;
+			if ( $t->{line} =~ m/$PPI::Token::Unknown::CURLY_SYMBOL/gc ) {
 				# This is really a dereference. ( $${^_foo} )
 				# Add the current token as the cast...
 				$t->{token} = PPI::Token::Cast->new( '$' );
@@ -216,8 +176,8 @@ sub __TOKENIZER__on_char {
 		$t->{line_cursor} += length( $c ) - length( $t->{token}->{content} );
 		$t->{token}->{content} = $c;
 	} else {
-		my $line = substr( $t->{line}, $t->{line_cursor} );
-		if ( $line =~ /($PPI::Token::Unknown::CURLY_SYMBOL)/ ) {
+		pos $t->{line} = $t->{line_cursor};
+		if ( $t->{line} =~ m/($PPI::Token::Unknown::CURLY_SYMBOL)/gc ) {
 			# control character symbol (e.g. ${^MATCH})
 			$t->{token}->{content} .= $1;
 			$t->{line_cursor}      += length $1;
