@@ -31,7 +31,7 @@ use PPI::Token::Number ();
 
 use vars qw{$VERSION @ISA};
 BEGIN {
-	$VERSION = '1.214_02';
+	$VERSION = '1.216_01';
 	@ISA     = 'PPI::Token::Number';
 }
 
@@ -43,7 +43,7 @@ Returns the base for the number: 16.
 
 =cut
 
-sub base () { 16 }
+sub base() { 16 }
 
 =pod
 
@@ -57,7 +57,7 @@ sub literal {
 	my $self = shift;
 	my $str = $self->_literal;
 	my $neg = $str =~ s/^\-//;
-	my $val = hex $str;
+	my $val = hex lc( $str ); # lc for compatibility with perls before 5.14
 	return $neg ? -$val : $val;
 }
 
@@ -76,7 +76,7 @@ sub __TOKENIZER__on_char {
 	# Allow underscores straight through
 	return 1 if $char eq '_';
 
-	if ( $char =~ /[\da-f]/ ) {
+	if ( $char =~ /[\da-f]/i ) {
 		return 1;
 	}
 
