@@ -50,7 +50,7 @@ use PPI::Token ();
 
 use vars qw{$VERSION @ISA};
 BEGIN {
-	$VERSION = '1.214_02';
+	$VERSION = '1.216_01';
 	@ISA     = 'PPI::Token';
 }
 
@@ -75,29 +75,6 @@ of the quotes.
   q{foo}
   qq <foo>
 
-=begin testing string 15
-
-# Prove what we say in the ->string docs
-my $Document = PPI::Document->new(\<<'END_PERL');
-  'foo'
-  "foo"
-  q{foo}
-  qq <foo>
-END_PERL
-isa_ok( $Document, 'PPI::Document' );
-
-my $quotes = $Document->find('Token::Quote');
-is( ref($quotes), 'ARRAY', 'Found quotes' );
-is( scalar(@$quotes), 4, 'Found 4 quotes' );
-foreach my $Quote ( @$quotes ) {
-	isa_ok( $Quote, 'PPI::Token::Quote');
-	can_ok( $Quote, 'string'           );
-	is( $Quote->string, 'foo', '->string returns "foo" for '
-		. $Quote->content );
-}
-
-=end testing
-
 =cut
 
 #sub string {
