@@ -30,8 +30,6 @@ There are no methods available for C<PPI::Token::Quote::Single> beyond
 those provided by the parent L<PPI::Token::Quote>, L<PPI::Token> and
 L<PPI::Element> classes.
 
-Got any ideas for methods? Submit a report to rt.cpan.org!
-
 =cut
 
 use strict;
@@ -40,7 +38,7 @@ use PPI::Token::_QuoteEngine::Simple ();
 
 use vars qw{$VERSION @ISA};
 BEGIN {
-	$VERSION = '1.214_02';
+	$VERSION = '1.216_01';
 	@ISA     = qw{
 		PPI::Token::_QuoteEngine::Simple
 		PPI::Token::Quote
@@ -54,51 +52,11 @@ BEGIN {
 #####################################################################
 # PPI::Token::Quote Methods
 
-=pod
-
-=begin testing string 3
-
-my $Document = PPI::Document->new( \"print 'foo';" );
-isa_ok( $Document, 'PPI::Document' );
-my $Single = $Document->find_first('Token::Quote::Single');
-isa_ok( $Single, 'PPI::Token::Quote::Single' );
-is( $Single->string, 'foo', '->string returns as expected' );
-
-=end testing
-
-=cut
-
 sub string {
 	my $str = $_[0]->{content};
 	substr( $str, 1, length($str) - 2 );
 }
 
-=pod
-
-=begin testing literal 21
-
-my @pairs = (
-	"''",          '',
-	"'f'",         'f',
-	"'f\\'b'",     "f\'b",
-	"'f\\nb'",     "f\\nb",
-	"'f\\\\b'",    "f\\b",
-	"'f\\\\\\b'", "f\\\\b",
-	"'f\\\\\\\''", "f\\'",
-);
-while ( @pairs ) {
-	my $from  = shift @pairs;
-	my $to    = shift @pairs;
-	my $doc   = PPI::Document->new( \"print $from;" );
-	isa_ok( $doc, 'PPI::Document' );
-	my $quote = $doc->find_first('Token::Quote::Single');
-	isa_ok( $quote, 'PPI::Token::Quote::Single' );
-	is( $quote->literal, $to, "The source $from becomes $to ok" );
-}
-
-=end testing 
-
-=cut
 
 my %UNESCAPE = (
 	"\\'"  => "'",
