@@ -40,7 +40,7 @@ use PPI::Token ();
 
 use vars qw{$VERSION @ISA %OPERATOR %QUOTELIKE};
 BEGIN {
-	$VERSION = '1.214_02';
+	$VERSION = '1.216_01';
 	@ISA     = 'PPI::Token';
 
 	# Copy in OPERATOR from PPI::Token::Operator
@@ -68,25 +68,6 @@ incorrectly) that the Word is a bareword and not a function, method,
 keyword, etc.  This differs from C<content> because C<Foo'Bar> expands
 to C<Foo::Bar>.
 
-=begin testing literal 9
-
-my @pairs = (
-	"F",          'F',
-	"Foo::Bar",   'Foo::Bar',
-	"Foo'Bar",    'Foo::Bar',
-);
-while ( @pairs ) {
-	my $from  = shift @pairs;
-	my $to    = shift @pairs;
-	my $doc   = PPI::Document->new( \"$from;" );
-	isa_ok( $doc, 'PPI::Document' );
-	my $word = $doc->find_first('Token::Word');
-	isa_ok( $word, 'PPI::Token::Word' );
-	is( $word->literal, $to, "The source $from becomes $to ok" );
-}
-
-=end testing
-
 =cut
 
 sub literal {
@@ -106,107 +87,6 @@ sub literal {
 Answers whether this is the name of a method in a method call. Returns true if
 yes, false if no, and nothing if unknown.
 
-=begin testing method_call 24
-
-my $Document = PPI::Document->new(\<<'END_PERL');
-indirect $foo;
-indirect_class_with_colon Foo::;
-$bar->method_with_parentheses;
-print SomeClass->method_without_parentheses + 1;
-sub_call();
-$baz->chained_from->chained_to;
-a_first_thing a_middle_thing a_last_thing;
-(first_list_element, second_list_element, third_list_element);
-first_comma_separated_word, second_comma_separated_word, third_comma_separated_word;
-single_bareword_statement;
-{ bareword_no_semicolon_end_of_block }
-$buz{hash_key};
-fat_comma_left_side => $thingy;
-END_PERL
-
-isa_ok( $Document, 'PPI::Document' );
-my $words = $Document->find('Token::Word');
-is( scalar @{$words}, 23, 'Found the 23 test words' );
-my %words = map { $_ => $_ } @{$words};
-is(
-	scalar $words{indirect}->method_call,
-	undef,
-	'Indirect notation is unknown.',
-);
-is(
-	scalar $words{indirect_class_with_colon}->method_call,
-	1,
-	'Indirect notation with following word ending with colons is true.',
-);
-is(
-	scalar $words{method_with_parentheses}->method_call,
-	1,
-	'Method with parentheses is true.',
-);
-is(
-	scalar $words{method_without_parentheses}->method_call,
-	1,
-	'Method without parentheses is true.',
-);
-is(
-	scalar $words{print}->method_call,
-	undef,
-	'Plain print is unknown.',
-);
-is(
-	scalar $words{SomeClass}->method_call,
-	undef,
-	'Class in class method call is unknown.',
-);
-is(
-	scalar $words{sub_call}->method_call,
-	0,
-	'Subroutine call is false.',
-);
-is(
-	scalar $words{chained_from}->method_call,
-	1,
-	'Method that is chained from is true.',
-);
-is(
-	scalar $words{chained_to}->method_call,
-	1,
-	'Method that is chained to is true.',
-);
-is(
-	scalar $words{a_first_thing}->method_call,
-	undef,
-	'First bareword is unknown.',
-);
-is(
-	scalar $words{a_middle_thing}->method_call,
-	undef,
-	'Bareword in the middle is unknown.',
-);
-is(
-	scalar $words{a_last_thing}->method_call,
-	0,
-	'Bareword at the end is false.',
-);
-foreach my $false_word (
-	qw<
-		first_list_element second_list_element third_list_element
-		first_comma_separated_word second_comma_separated_word third_comma_separated_word
-		single_bareword_statement
-		bareword_no_semicolon_end_of_block
-		hash_key
-		fat_comma_left_side
-	>
-) {
-	is(
-		scalar $words{$false_word}->method_call,
-		0,
-		"$false_word is false.",
-	);
-}
-
-=end testing
-
 =cut
 
 sub method_call {
@@ -252,85 +132,6 @@ sub method_call {
 	return;
 }
 
-=begin testing __TOKENIZER__on_char 27
-
-my $Document = PPI::Document->new(\<<'END_PERL');
-$foo eq'bar';
-$foo ne'bar';
-$foo ge'bar';
-$foo le'bar';
-$foo gt'bar';
-$foo lt'bar';
-END_PERL
-
-isa_ok( $Document, 'PPI::Document' );
-my $words = $Document->find('Token::Operator');
-is( scalar @{$words}, 6, 'Found the 6 test operators' );
-
-is( $words->[0], 'eq', q{$foo eq'bar'} );
-is( $words->[1], 'ne', q{$foo ne'bar'} );
-is( $words->[2], 'ge', q{$foo ge'bar'} );
-is( $words->[3], 'le', q{$foo le'bar'} );
-is( $words->[4], 'gt', q{$foo ht'bar'} );
-is( $words->[5], 'lt', q{$foo lt'bar'} );
-
-$Document = PPI::Document->new(\<<'END_PERL');
-q'foo';
-qq'foo';
-END_PERL
-
-isa_ok( $Document, 'PPI::Document' );
-$words = $Document->find('Token::Quote');
-is( scalar @{$words}, 2, 'Found the 2 test quotes' );
-
-is( $words->[0], q{q'foo'}, q{q'foo'} );
-is( $words->[1], q{qq'foo'}, q{qq'foo'} );
-
-$Document = PPI::Document->new(\<<'END_PERL');
-qx'foo';
-qw'foo';
-qr'foo';
-END_PERL
-
-isa_ok( $Document, 'PPI::Document' );
-$words = $Document->find('Token::QuoteLike');
-is( scalar @{$words}, 3, 'Found the 3 test quotelikes' );
-
-is( $words->[0], q{qx'foo'}, q{qx'foo'} );
-is( $words->[1], q{qw'foo'}, q{qw'foo'} );
-is( $words->[2], q{qr'foo'}, q{qr'foo'} );
-
-$Document = PPI::Document->new(\<<'END_PERL');
-m'foo';
-s'foo'bar';
-tr'fo'ba';
-y'fo'ba';
-END_PERL
-
-isa_ok( $Document, 'PPI::Document' );
-$words = $Document->find('Token::Regexp');
-is( scalar @{$words}, 4, 'Found the 4 test quotelikes' );
-
-is( $words->[0], q{m'foo'},     q{m'foo'} );
-is( $words->[1], q{s'foo'bar'}, q{s'foo'bar'} );
-is( $words->[2], q{tr'fo'ba'},  q{tr'fo'ba'} );
-is( $words->[3], q{y'fo'ba'},   q{y'fo'ba'} );
-
-$Document = PPI::Document->new(\<<'END_PERL');
-pack'H*',$data;
-unpack'H*',$data;
-END_PERL
-
-isa_ok( $Document, 'PPI::Document' );
-$words = $Document->find('Token::Word');
-is( scalar @{$words}, 2, 'Found the 2 test words' );
-
-is( $words->[0], 'pack', q{pack'H*',$data} );
-is( $words->[1], 'unpack', q{unpack'H*',$data} );
-
-=end testing
-
-=cut
 
 my %backoff = map { $_ => 1 } qw{
     eq ne ge le gt lt
@@ -343,8 +144,8 @@ sub __TOKENIZER__on_char {
 	my $t     = shift;
 
 	# Suck in till the end of the bareword
-	my $rest = substr( $t->{line}, $t->{line_cursor} );
-	if ( $rest =~ /^(\w+(?:(?:\'|::)\w+)*(?:::)?)/ ) {
+	pos $t->{line} = $t->{line_cursor};
+	if ( $t->{line} =~ m/\G(\w+(?:(?:\'|::)\w+)*(?:::)?)/gc ) {
 		my $word = $1;
 		# Special Case: If we accidentally treat eq'foo' like
 		# the word "eq'foo", then just make 'eq' (or whatever
@@ -410,10 +211,10 @@ sub __TOKENIZER__commit {
 
 	# Our current position is the first character of the bareword.
 	# Capture the bareword.
-	my $rest = substr( $t->{line}, $t->{line_cursor} );
-	unless ( $rest =~ /^((?!\d)\w+(?:(?:\'|::)\w+)*(?:::)?)/ ) {
+	pos $t->{line} = $t->{line_cursor};
+	unless ( $t->{line} =~ m/\G((?!\d)\w+(?:(?:\'|::)\w+)*(?:::)?)/gc ) {
 		# Programmer error
-		die "Fatal error... regex failed to match in '$rest' when expected";
+		die sprintf "Fatal error... regex failed to match in '%s' when expected", substr $t->{line}, $t->{line_cursor};
 	}
 
 	# Special Case: If we accidentally treat eq'foo' like the word "eq'foo",
@@ -446,14 +247,14 @@ sub __TOKENIZER__commit {
 		# Add the rest of the line as a comment, and a whitespace newline
 		# Anything after the __END__ on the line is "ignored". So we must
 		# also ignore it, by turning it into a comment.
-		$rest = substr( $t->{line}, $t->{line_cursor} );
+		my $end_rest = substr( $t->{line}, $t->{line_cursor} );
 		$t->{line_cursor} = length $t->{line};
-		if ( $rest =~ /\n$/ ) {
-			chomp $rest;
-			$t->_new_token( 'Comment', $rest ) if length $rest;
+		if ( $end_rest =~ /\n$/ ) {
+			chomp $end_rest;
+			$t->_new_token( 'Comment', $end_rest ) if length $end_rest;
 			$t->_new_token( 'Whitespace', "\n" );
 		} else {
-			$t->_new_token( 'Comment', $rest ) if length $rest;
+			$t->_new_token( 'Comment', $end_rest ) if length $end_rest;
 		}
 		$t->_finalize_token;
 
@@ -470,14 +271,14 @@ sub __TOKENIZER__commit {
 		$t->{zone} = 'PPI::Token::Data';
 
 		# Add the rest of the line as the Data token
-		$rest = substr( $t->{line}, $t->{line_cursor} );
+		my $data_rest = substr( $t->{line}, $t->{line_cursor} );
 		$t->{line_cursor} = length $t->{line};
-		if ( $rest =~ /\n$/ ) {
-			chomp $rest;
-			$t->_new_token( 'Comment', $rest ) if length $rest;
+		if ( $data_rest =~ /\n$/ ) {
+			chomp $data_rest;
+			$t->_new_token( 'Comment', $data_rest ) if length $data_rest;
 			$t->_new_token( 'Whitespace', "\n" );
 		} else {
-			$t->_new_token( 'Comment', $rest ) if length $rest;
+			$t->_new_token( 'Comment', $data_rest ) if length $data_rest;
 		}
 		$t->_finalize_token;
 
@@ -498,14 +299,14 @@ sub __TOKENIZER__commit {
 		return ($t->{line_cursor} >= $t->{line_length}) ? 0
 			: $t->{class}->__TOKENIZER__on_char( $t );
 
-	} elsif ( $OPERATOR{$word} ) {
+	} elsif ( $OPERATOR{$word} && ($word ne 'x' || $t->_current_x_is_operator) ) {
 		# Word operator
 		$token_class = 'Operator';
 
 	} else {
 		# If the next character is a ':' then its a label...
-		my $string = substr( $t->{line}, $t->{line_cursor} );
-		if ( $string =~ /^(\s*:)(?!:)/ ) {
+		pos $t->{line} = $t->{line_cursor};
+		if ( $t->{line} =~ m/\G(\s*:)(?!:)/gc ) {
 			if ( $tokens and $tokens->[0]->{content} eq 'sub' ) {
 				# ... UNLESS its after 'sub' in which
 				# case it is a sub name and an attribute
@@ -552,7 +353,7 @@ sub __TOKENIZER__literal {
 	}
 
 	# Check the cases when we have previous tokens
-	my $rest = substr( $t->{line}, $t->{line_cursor} );
+	pos $t->{line} = $t->{line_cursor};
 	if ( $tokens ) {
 		my $token = $tokens->[0] or return '';
 
@@ -564,18 +365,18 @@ sub __TOKENIZER__literal {
 
 		# If we are contained in a pair of curly braces,
 		# we are probably a bareword hash key
-		if ( $token->{content} eq '{' and $rest =~ /^\s*\}/ ) {
+		if ( $token->{content} eq '{' and $t->{line} =~ /\G\s*\}/gc ) {
 			return 1;
 		}
 	}
 
 	# In addition, if the word is followed by => it is probably
 	# also actually a word and not a regex.
-	if ( $rest =~ /^\s*=>/ ) {
+	if ( $t->{line} =~ /\G\s*=>/gc ) {
 		return 1;
 	}
 
-	# Otherwise we probably arn't forced
+	# Otherwise we probably aren't forced
 	'';
 }
 
